@@ -26,6 +26,7 @@ namespace xsimd
         using value_type = bool;
         static constexpr std::size_t size = 8;
         using batch_type = batch<int32_t, 8>;
+        static constexpr std::size_t align = 32;
     };
 
     template <>
@@ -68,6 +69,7 @@ namespace xsimd
         using value_type = int32_t;
         static constexpr std::size_t size = 8;
         using batch_bool_type = batch_bool<int32_t, 8>;
+        static constexpr std::size_t align = 32;
     };
 
     template <>
@@ -150,8 +152,6 @@ namespace xsimd
 
     batch<int32_t, 8> operator<<(const batch<int32_t, 8>& lhs, int32_t rhs);
     batch<int32_t, 8> operator>>(const batch<int32_t, 8>& lhs, int32_t rhs);
-    batch<int32_t, 8> operator<<(const batch<int32_t, 8>& lhs, const batch<int32_t, 8>& rhs);
-    batch<int32_t, 8> operator>>(const batch<int32_t, 8>& lhs, const batch<int32_t, 8>& rhs);
 
     /*****************************************
      * batch_bool<int32_t, 8> implementation *
@@ -674,34 +674,6 @@ namespace xsimd
         XSIMD_RETURN_MERGED_SSE(res_low, res_high);
 #endif
     }
-
-    inline batch<int32_t, 8> operator<<(const batch<int32_t, 8>& lhs, const batch<int32_t, 8>& rhs)
-    {
-        return batch<int32_t, 8>{
-            lhs[0] << rhs[0],
-            lhs[1] << rhs[1],
-            lhs[2] << rhs[2],
-            lhs[3] << rhs[3],
-            lhs[4] << rhs[4],
-            lhs[5] << rhs[5],
-            lhs[6] << rhs[6],
-            lhs[7] << rhs[7]
-            };
-    }
-
-    inline batch<int32_t, 8> operator>>(const batch<int32_t, 8>& lhs, const batch<int32_t, 8>& rhs)
-    {
-        return batch<int32_t, 8>{
-            lhs[0] >> rhs[0],
-            lhs[1] >> rhs[1],
-            lhs[2] >> rhs[2],
-            lhs[3] >> rhs[3],
-            lhs[4] >> rhs[4],
-            lhs[5] >> rhs[5],
-            lhs[6] >> rhs[6],
-            lhs[7] >> rhs[7]
-            };
-    }
 }
 
 #undef XSIMD_APPLY_SSE_FUNCTION
