@@ -26,6 +26,7 @@ namespace xsimd
         using value_type = bool;
         static constexpr std::size_t size = 4;
         using batch_type = batch<int64_t, 4>;
+        static constexpr std::size_t align = 32;
     };
 
     template <>
@@ -68,6 +69,7 @@ namespace xsimd
         using value_type = int64_t;
         static constexpr std::size_t size = 4;
         using batch_bool_type = batch_bool<int64_t, 4>;
+        static constexpr std::size_t align = 32;
     };
 
     template <>
@@ -151,8 +153,6 @@ namespace xsimd
 
     batch<int64_t, 4> operator<<(const batch<int64_t, 4>& lhs, int32_t rhs);
     batch<int64_t, 4> operator>>(const batch<int64_t, 4>& lhs, int32_t rhs);
-    batch<int64_t, 4> operator<<(const batch<int64_t, 4>& lhs, const batch<int64_t, 4>& rhs);
-    batch<int64_t, 4> operator>>(const batch<int64_t, 4>& lhs, const batch<int64_t, 4>& rhs);
 
     /*****************************************
      * batch_bool<int64_t, 4> implementation *
@@ -702,26 +702,6 @@ namespace xsimd
         XSIMD_RETURN_MERGED_SSE(res_low, res_high);
 #endif
     }
-
-    inline batch<int64_t, 4> operator<<(const batch<int64_t, 4>& lhs, const batch<int64_t, 4>& rhs)
-    {
-        return batch<int64_t, 4>{
-            lhs[0] << rhs[0],
-            lhs[1] << rhs[1],
-            lhs[2] << rhs[2],
-            lhs[3] << rhs[3]
-            };
-    }
-
-    inline batch<int64_t, 4> operator>>(const batch<int64_t, 4>& lhs, const batch<int64_t, 4>& rhs)
-    {
-        return batch<int64_t, 4>{
-            lhs[0] >> rhs[0],
-            lhs[1] >> rhs[1],
-            lhs[2] >> rhs[2],
-            lhs[3] >> rhs[3]
-            };
-    }
 }
 
 #undef XSIMD_APPLY_SSE_FUNCTION
