@@ -26,6 +26,7 @@ namespace xsimd
         using value_type = bool;
         static constexpr std::size_t size = 4;
         using batch_type = batch<int32_t, 4>;
+        static constexpr std::size_t align = 16;
     };
 
     template <>
@@ -68,6 +69,7 @@ namespace xsimd
         using value_type = int32_t;
         static constexpr std::size_t size = 4;
         using batch_bool_type = batch_bool<int32_t, 4>;
+        static constexpr std::size_t align = 16;
     };
 
     template <>
@@ -150,8 +152,6 @@ namespace xsimd
 
     batch<int32_t, 4> operator<<(const batch<int32_t, 4>& lhs, int32_t rhs);
     batch<int32_t, 4> operator>>(const batch<int32_t, 4>& lhs, int32_t rhs);
-    batch<int32_t, 4> operator<<(const batch<int32_t, 4>& lhs, const batch<int32_t, 4>& rhs);
-    batch<int32_t, 4> operator>>(const batch<int32_t, 4>& lhs, const batch<int32_t, 4>& rhs);
 
     /*****************************************
      * batch_bool<int32_t, 4> implementation *
@@ -562,26 +562,6 @@ namespace xsimd
     {
         return _mm_srli_epi32(lhs, rhs);
     }
-
-    inline batch<int32_t, 4> operator<<(const batch<int32_t, 4>& lhs, const batch<int32_t, 4>& rhs)
-    {
-        return batch<int32_t, 4>{
-            lhs[0] << rhs[0],
-            lhs[1] << rhs[1],
-            lhs[2] << rhs[2],
-            lhs[3] << rhs[3]
-            };
-    }
-
-    inline batch<int32_t, 4> operator>>(const batch<int32_t, 4>& lhs, const batch<int32_t, 4>& rhs)
-    {
-        return batch<int32_t, 4>{
-            lhs[0] >> rhs[0],
-            lhs[1] >> rhs[1],
-            lhs[2] >> rhs[2],
-            lhs[3] >> rhs[3]
-            };
-    }
 }
 
 #endif
